==> filevault-package-maven-plugin-1.1.6-source-release.zip: filevault-package-maven-plugin-1.1.6/README.md <==
[![ASF Jira](https://img.shields.io/badge/ASF%20JIRA-JCRVLT-orange)](https://issues.apache.org/jira/projects/JCRVLT/summary)
![GitHub](https://img.shields.io/github/license/apache/jackrabbit-filevault-package-maven-plugin)
[![Maven Central](https://img.shields.io/maven-central/v/org.apache.jackrabbit/filevault-package-maven-plugin.svg?label=Maven%20Central)](https://search.maven.org/artifact/org.apache.jackrabbit/filevault-package-maven-plugin)
[![Build Status](https://travis-ci.org/apache/jackrabbit-filevault-package-maven-plugin.svg?branch=master)](https://travis-ci.org/apache/jackrabbit-filevault-package-maven-plugin)
[![SonarCloud Status](https://sonarcloud.io/api/project_badges/measure?project=apache_jackrabbit-filevault-package-maven-plugin&metric=alert_status)](https://sonarcloud.io/dashboard?id=apache_jackrabbit-filevault-package-maven-plugin)
[![SonarCloud Coverage](https://sonarcloud.io/api/project_badges/measure?project=apache_jackrabbit-filevault-package-maven-plugin&metric=coverage)](https://sonarcloud.io/component_measures/metric/coverage/list?id=apache_jackrabbit-filevault-package-maven-plugin)
[![SonarCloud Bugs](https://sonarcloud.io/api/project_badges/measure?project=apache_jackrabbit-filevault-package-maven-plugin&metric=bugs)](https://sonarcloud.io/component_measures/metric/reliability_rating/list?id=apache_jackrabbit-filevault-package-maven-plugin)
[![SonarCloud Vulnerabilities](https://sonarcloud.io/api/project_badges/measure?project=apache_jackrabbit-filevault-package-maven-plugin&metric=vulnerabilities)](https://sonarcloud.io/component_measures/metric/security_rating/list?id=apache_jackrabbit-filevault-package-maven-plugin)

Welcome to Apache Jackrabbit FileVault Package Maven Plugin
===========================================================

The Apache Jackrabbit FileVault Package Maven Plugin is an Apache Maven Plugin 
that simplifies the creation of content package Maven artifacts. The content 
packages can later be used to install content into a JCR repository using the 
Apache Jackrabbit FileVault packaging runtime.

Apache Jackrabbit FileVault is a project of the Apache Software Foundation.

Documentation
=============
Please refer to the plugin documentation at 
<https://jackrabbit.apache.org/filevault-package-maven-plugin/index.html>


Building the FileVault Package Maven Plugin
===========================================

You can build the plugin like this:

    mvn clean install

You need Maven 3.3.9 (or higher) with Java 8 (or higher) for the build.
For more instructions, please see the documentation at:

   <https://jackrabbit.apache.org/building-jackrabbit.html>

License (see also LICENSE)
==============================

```
Collective work: Copyright 2013 The Apache Software Foundation.

Licensed to the Apache Software Foundation (ASF) under one or more
contributor license agreements.  See the NOTICE file distributed with
this work for additional information regarding copyright ownership.
The ASF licenses this file to You under the Apache License, Version 2.0
(the "License"); you may not use this file except in compliance with
the License.  You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
```

Mailing Lists
=============

To get involved with the Apache Jackrabbit project, start by having a
look at our website and joining our mailing lists. For more details about
Jackrabbit mailing lists as well as links to list archives, please see:

   <https://jackrabbit.apache.org/mailing-lists.html>

Latest development
==================

The latest FileVault package plugin source code is available at

   <https://github.com/apache/jackrabbit-filevault-package-maven-plugin>


Credits
=======

See <https://jackrabbit.apache.org/jackrabbit-team.html> for the list of
Jackrabbit committers and main contributors.

==> filevault-package-maven-plugin-1.1.8-source-release.zip: filevault-package-maven-plugin-1.1.8/README.md <==
[![ASF Jira](https://img.shields.io/badge/ASF%20JIRA-JCRVLT-orange)](https://issues.apache.org/jira/projects/JCRVLT/summary)
![GitHub](https://img.shields.io/github/license/apache/jackrabbit-filevault-package-maven-plugin)
[![Maven Central](https://img.shields.io/maven-central/v/org.apache.jackrabbit/filevault-package-maven-plugin.svg?label=Maven%20Central)](https://search.maven.org/artifact/org.apache.jackrabbit/filevault-package-maven-plugin)
[![Build Status](https://travis-ci.com/apache/jackrabbit-filevault-package-maven-plugin.svg?branch=master)](https://travis-ci.com/apache/jackrabbit-filevault-package-maven-plugin)
[![SonarCloud Status](https://sonarcloud.io/api/project_badges/measure?project=apache_jackrabbit-filevault-package-maven-plugin&metric=alert_status)](https://sonarcloud.io/dashboard?id=apache_jackrabbit-filevault-package-maven-plugin)
[![SonarCloud Coverage](https://sonarcloud.io/api/project_badges/measure?project=apache_jackrabbit-filevault-package-maven-plugin&metric=coverage)](https://sonarcloud.io/component_measures/metric/coverage/list?id=apache_jackrabbit-filevault-package-maven-plugin)
[![SonarCloud Bugs](https://sonarcloud.io/api/project_badges/measure?project=apache_jackrabbit-filevault-package-maven-plugin&metric=bugs)](https://sonarcloud.io/component_measures/metric/reliability_rating/list?id=apache_jackrabbit-filevault-package-maven-plugin)
[![SonarCloud Vulnerabilities](https://sonarcloud.io/api/project_badges/measure?project=apache_jackrabbit-filevault-package-maven-plugin&metric=vulnerabilities)](https://sonarcloud.io/component_measures/metric/security_rating/list?id=apache_jackrabbit-filevault-package-maven-plugin)

Welcome to Apache Jackrabbit FileVault Package Maven Plugin
===========================================================

The Apache Jackrabbit FileVault Package Maven Plugin is an Apache Maven Plugin 
that simplifies the creation of content package Maven artifacts. The content 
packages can later be used to install content into a JCR repository using the 
Apache Jackrabbit FileVault packaging runtime.

Apache Jackrabbit FileVault is a project of the Apache Software Foundation.

Documentation
=============
Please refer to the plugin documentation at 
<https://jackrabbit.apache.org/filevault-package-maven-plugin/index.html>


Building the FileVault Package Maven Plugin
===========================================

You can build the plugin like this:

    mvn clean install

You need Maven 3.3.9 (or higher) with Java 8 (or higher) for the build.
For more instructions, please see the documentation at:

   <https://jackrabbit.apache.org/building-jackrabbit.html>

License (see also LICENSE)
==============================

```
Collective work: Copyright 2013 The Apache Software Foundation.

Licensed to the Apache Software Foundation (ASF) under one or more
contributor license agreements.  See the NOTICE file distributed with
this work for additional information regarding copyright ownership.
The ASF licenses this file to You under the Apache License, Version 2.0
(the "License"); you may not use this file except in compliance with
the License.  You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
```

Mailing Lists
=============

To get involved with the Apache Jackrabbit project, start by having a
look at our website and joining our mailing lists. For more details about
Jackrabbit mailing lists as well as links to list archives, please see:

   <https://jackrabbit.apache.org/mailing-lists.html>

Latest development
==================

The latest FileVault package plugin source code is available at

   <https://github.com/apache/jackrabbit-filevault-package-maven-plugin>


Credits
=======

See <https://jackrabbit.apache.org/jackrabbit-team.html> for the list of
Jackrabbit committers and main contributors.
